Ksc.Compiler.Utils (Ksc v0.1.0)

Copy Markdown View Source

Name conversion and code generation helpers.

Summary

Functions

Indent a block of code by the given number of spaces.

Join code blocks with double newlines.

Convert snake_case id to CamelCase module name.

Functions

indent(code, level)

Indent a block of code by the given number of spaces.

join_code(blocks)

Join code blocks with double newlines.

to_module_name(id)

Convert snake_case id to CamelCase module name.