Name conversion and code generation helpers.
Summary
Functions
Indent a block of code by the given number of spaces.
Join code blocks with double newlines.
Convert snake_case id to CamelCase module name.
Name conversion and code generation helpers.
Indent a block of code by the given number of spaces.
Join code blocks with double newlines.
Convert snake_case id to CamelCase module name.